=== modified file 'drizzled/cached_item.cc'
--- drizzled/cached_item.cc	2008-11-18 22:12:56 +0000
+++ drizzled/cached_item.cc	2009-06-23 21:20:32 +0000
@@ -28,6 +28,9 @@
 #include <drizzled/cached_item.h>
 #include <drizzled/sql_string.h>
 #include <drizzled/session.h>
+#include <algorithm>
+
+using namespace std;
 
 /**
   Create right type of Cached_item for an item.
@@ -70,8 +73,8 @@
 */
 
 Cached_item_str::Cached_item_str(Session *session, Item *arg)
-  :item(arg), value(cmin(arg->max_length,
-                         (uint32_t)session->variables.max_sort_length))
+  :item(arg), value(min(arg->max_length,
+                        (uint32_t)session->variables.max_sort_length))
 {}
 
 bool Cached_item_str::cmp(void)
@@ -80,7 +83,7 @@
   bool tmp;
 
   if ((res=item->val_str(&tmp_value)))
-    res->length(cmin(res->length(), value.alloced_length()));
+    res->length(min(res->length(), value.alloced_length()));
 
   if (null_value != item->null_value)
   {

=== modified file 'drizzled/create_field.cc'
--- drizzled/create_field.cc	2009-06-13 21:21:13 +0000
+++ drizzled/create_field.cc	2009-06-23 21:20:32 +0000
@@ -43,6 +43,11 @@
 #include "drizzled/field/datetime.h"
 #include "drizzled/field/varstring.h"
 
+#include <algorithm>
+
+using namespace std;
+
+
 /** Create a field suitable for create of table. */
 CreateField::CreateField(Field *old_field, Field *orig_field)
 {
@@ -300,7 +305,7 @@
           and 19 as length of 4.1 compatible representation.
         */
         length= ((length+1)/2)*2; /* purecov: inspected */
-        length= cmin(length, (uint32_t)MAX_DATETIME_COMPRESSED_WIDTH); /* purecov: inspected */
+        length= min(length, (uint32_t)MAX_DATETIME_COMPRESSED_WIDTH); /* purecov: inspected */
       }
       flags|= UNSIGNED_FLAG;
       if (fld_default_value)

=== modified file 'drizzled/field/blob.cc'
--- drizzled/field/blob.cc	2009-06-13 21:21:13 +0000
+++ drizzled/field/blob.cc	2009-06-23 21:20:32 +0000
@@ -25,6 +25,7 @@
 #include <drizzled/session.h>
 
 #include <string>
+#include <algorithm>
 
 using namespace std;
 
@@ -32,7 +33,7 @@
 blob_pack_length_to_max_length(uint32_t arg)
 {
   return (uint32_t)cmax(UINT32_MAX,
-                        (INT64_C(1) << cmin(arg, 4U) * 8) - INT64_C(1));
+                        (INT64_C(1) << min(arg, 4U) * 8) - INT64_C(1));
 }
 
 
@@ -220,7 +221,7 @@
     from= tmpstr.ptr();
   }
 
-  new_length= cmin(max_data_length(), field_charset->mbmaxlen * length);
+  new_length= min(max_data_length(), field_charset->mbmaxlen * length);
   if (value.alloc(new_length))
     goto oom_error;
 
@@ -363,20 +364,26 @@
 
 
 int Field_blob::cmp_binary(const unsigned char *a_ptr, const unsigned char *b_ptr,
-			   uint32_t max_length)
+                           uint32_t max_length)
 {
   char *a,*b;
   uint32_t diff;
   uint32_t a_length,b_length;
   memcpy(&a,a_ptr+packlength,sizeof(char*));
   memcpy(&b,b_ptr+packlength,sizeof(char*));
-  a_length=get_length(a_ptr);
+
+  a_length= get_length(a_ptr);
+
   if (a_length > max_length)
-    a_length=max_length;
-  b_length=get_length(b_ptr);
+    a_length= max_length;
+
+  b_length= get_length(b_ptr);
+
   if (b_length > max_length)
-    b_length=max_length;
-  diff=memcmp(a,b,cmin(a_length,b_length));
+    b_length= max_length;
+
+  diff= memcmp(a,b,min(a_length,b_length));
+
   return diff ? diff : (int) (a_length - b_length);
 }
 
@@ -540,18 +547,18 @@
 }
 
 unsigned char *Field_blob::pack(unsigned char *to, const unsigned char *from,
-                        uint32_t max_length, bool low_byte_first)
+                                uint32_t max_length, bool low_byte_first)
 {
   unsigned char *save= ptr;
   ptr= (unsigned char*) from;
-  uint32_t length=get_length();			// Length of from string
+  uint32_t length= get_length();			// Length of from string
 
   /*
     Store max length, which will occupy packlength bytes. If the max
     length given is smaller than the actual length of the blob, we
     just store the initial bytes of the blob.
   */
-  store_length(to, packlength, cmin(length, max_length), low_byte_first);
+  store_length(to, packlength, min(length, max_length), low_byte_first);
 
   /*
     Store the actual blob data, which will occupy 'length' bytes.
@@ -561,7 +568,8 @@
     get_ptr((unsigned char**) &from);
     memcpy(to+packlength, from,length);
   }
-  ptr=save;					// Restore org row pointer
+
+  ptr= save;					// Restore org row pointer
   return(to+packlength+length);
 }
 

=== modified file 'drizzled/filesort.cc'
--- drizzled/filesort.cc	2009-05-22 23:10:48 +0000
+++ drizzled/filesort.cc	2009-06-23 21:20:32 +0000
@@ -30,6 +30,7 @@
 #include <drizzled/table_list.h>
 
 #include <queue>
+#include <algorithm>
 
 using namespace std;
 
@@ -183,8 +184,8 @@
 #ifdef CAN_TRUST_RANGE
   if (select && select->quick && select->quick->records > 0L)
   {
-    records=cmin((ha_rows) (select->quick->records*2+EXTRA_RECORDS*2),
-		table->file->stats.records)+EXTRA_RECORDS;
+    records= min((ha_rows) (select->quick->records*2+EXTRA_RECORDS*2),
+                 table->file->stats.records)+EXTRA_RECORDS;
     selected_records_file=0;
   }
   else
@@ -210,7 +211,7 @@
   {
     uint32_t old_memavl;
     uint32_t keys= memavl/(param.rec_length+sizeof(char*));
-    param.keys=(uint32_t) cmin(records+1, keys);
+    param.keys= (uint32_t) min(records+1, (ha_rows)keys);
     if ((table_sort.sort_keys=
 	 (unsigned char **) make_char_array((char **) table_sort.sort_keys,
                                             param.keys, param.rec_length)))
@@ -1036,18 +1037,19 @@
 */
 
 uint32_t read_to_buffer(IO_CACHE *fromfile, BUFFPEK *buffpek,
-		    uint32_t rec_length)
+                        uint32_t rec_length)
 {
   register uint32_t count;
   uint32_t length;
 
-  if ((count=(uint32_t) cmin((ha_rows) buffpek->max_keys,buffpek->count)))
+  if ((count= (uint32_t) min((ha_rows) buffpek->max_keys,buffpek->count)))
   {
     if (pread(fromfile->file,(unsigned char*) buffpek->base, (length= rec_length*count),buffpek->file_pos) == 0)
       return((uint32_t) -1);			/* purecov: inspected */
-    buffpek->key=buffpek->base;
+
+    buffpek->key= buffpek->base;
     buffpek->file_pos+= length;			/* New filepos */
-    buffpek->count-=	count;
+    buffpek->count-= count;
     buffpek->mem_count= count;
   }
   return (count*rec_length);
@@ -1286,7 +1288,7 @@
          != -1 && error != 0);
 
 end:
-  lastbuff->count= cmin(org_max_rows-max_rows, param->max_rows);
+  lastbuff->count= min(org_max_rows-max_rows, param->max_rows);
   lastbuff->file_pos= to_start_filepos;
 err:
   return(error);

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2009-06-11 21:44:00 +0000
+++ drizzled/session.cc	2009-06-23 21:20:32 +0000
@@ -37,6 +37,11 @@
 #include <drizzled/show.h>
 #include <drizzled/scheduling.h>
 
+#include <algorithm>
+
+using namespace std;
+
+
 /*
   The following is used to initialise Table_ident with a internal
   table name
@@ -1224,9 +1229,10 @@
     else
     {
       if (fixed_row_size)
-	used_length=cmin(res->length(),item->max_length);
+        used_length= min(res->length(),item->max_length);
       else
-	used_length=res->length();
+        used_length= res->length();
+
       if ((result_type == STRING_RESULT || is_unsafe_field_sep) &&
            escape_char != -1)
       {

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2009-06-13 21:21:13 +0000
+++ drizzled/table.cc	2009-06-23 21:20:32 +0000
@@ -33,6 +33,7 @@
 #include <drizzled/field/double.h>
 #include <string>
 #include <vector>
+#include <algorithm>
 
 #include <drizzled/unireg.h>
 #include <drizzled/message/table.pb.h>
@@ -2780,10 +2781,11 @@
     share->max_rows= ~(ha_rows) 0;
   else
     share->max_rows= (ha_rows) (((share->db_type() == heap_engine) ?
-                                 cmin(session->variables.tmp_table_size,
+                                 min(session->variables.tmp_table_size,
                                      session->variables.max_heap_table_size) :
                                  session->variables.tmp_table_size) /
-			         share->reclength);
+                                 share->reclength);
+
   set_if_bigger(share->max_rows,(ha_rows)1);	// For dummy start options
   /*
     Push the LIMIT clause to the temporary table creation, so that we

